# portalutils
[![Build Status](https://travis-ci.com/Jack-Kingdom/portalutils.svg?branch=master)](https://travis-ci.com/Jack-Kingdom/portalutils)

portal access utils.
![portalutils](https://raw.githubusercontent.com/wiki/Jack-Kingdom/portalutils/assets/portal.jpg)

## Install
```shell
pip install portalutils
```

## Documentation
Check [wiki](https://github.com/Jack-Kingdom/portalutils/wiki) for details.

## LICENSE
MIT